<template>
  <div class="layout-navbars-breadcrumb-index">
    <!-- 面包屑右边界面展示 -->
    <Logo v-if="setIsShowLogo" />
    <Breadcrumb />
    <!-- 横向布局 -->
    <Horizontal :menuList="menuList" v-if="isLayoutTransverse" />
    <User />
  </div>
</template>

<script setup lang="ts" name="layoutBreadcrumbIndex">
import { reactive, toRefs, onMounted, computed, onUnmounted } from 'vue'
import { useRoute } from 'vue-router'
import Logo from '/@/layout/logo/index.vue'
import Breadcrumb from '/@/layout/navBars/breadcrumb/breadcrumb.vue'
import { useThemeConfig } from '/@/stores/themeConfig';
import { storeToRefs } from 'pinia';

import Horizontal from '/@/layout/navMenu/horizontal.vue'
import { useRoutesList } from '/@/stores/routesList';
import User from '/@/layout/navBars/breadcrumb/user.vue'
import mittBus from '/@/utils/mitt'
const storesThemeConfig = useThemeConfig()
const { themeConfig } = storeToRefs(storesThemeConfig)
const stores = useRoutesList()
const { routesList } = storeToRefs(stores)
const route = useRoute()

// 定义接口来定义对象的类型
interface IndexState {
  menuList: object[]; // 等同 menuList:Array<object> 
}


// 设置 logo 显示/隐藏
const setIsShowLogo = computed(() => {
  let { isShowLogo, layout } = themeConfig.value
  return (isShowLogo && layout === 'classic') || (isShowLogo && layout === 'transverse')
})

const state = reactive<IndexState>({
  menuList: []
})
const { menuList } = toRefs(state)

// 设置是否显示横向导航菜单
const isLayoutTransverse = computed(() => {
  let { layout, isClassicSplitMenu } = themeConfig.value
  return layout === 'transverse' || (isClassicSplitMenu && layout === 'classic')//transverse横向或者classic经典设置显示横向导航菜单
})
// 设置/过滤路由（非静态路由/是否显示在菜单中）555
const setFilterRoutes = () => {
  let { layout, isClassicSplitMenu } = themeConfig.value
  if (layout === 'classic' && isClassicSplitMenu) {
    state.menuList = delClassicChildren(filterRoutesFun(routesList.value))
    const resData = setSendClassicChildren(route.path)
    mittBus.emit('setSendClassicChildren', resData)
  } else {
    // debugger
    state.menuList = filterRoutesFun(routesList.value)
    console.log(state.menuList)
  }
}
// 设置了分割菜单时，删除底下 children
const delClassicChildren = (arr: Array<object>) => {
  arr.map((v: any) => {
    if (v.children) delete v.children
  })
  return arr;
}
// 路由过滤递归函数
const filterRoutesFun = (arr: Array<string>) => {
  // debugger
  return arr
    .filter((item: any) => !item.meta.isHide)
    .map((item: any) => {
      item = Object.assign({}, item);//待研究问题55
      if (item.children) item.children = filterRoutesFun(item.children);//待研究问题55
      return item;
    });
}

// const bb=(arr:Array<object>)=>{
//   return arr
// 				.filter((item: any) => !item.meta.isHide)
// 				.map((item: any) => {
// 					item = Object.assign({}, item);//待研究问题55
// 					if (item.children) item.children = bb(item.children);//待研究问题55
// 					return item;
// 				});
// }

// let arry=[{path:'/home',meta:{isHide:false},children:[{path:'/homeaa',meta:{isHide:false},children:[{path:'/homebb',meta:{isHide:false}}]}]}]
// console.log(bb(arry))

// 传送当前子级数据到菜单中
const setSendClassicChildren = (path: string) => {
  const currentPathSplit = path.split('/')
  let currentData: any = {}
  filterRoutesFun(routesList.value).map((v, k) => {
    if (v.path === `/${currentPathSplit[1]}`) {
      v['k'] = k
      currentData['item'] = [{ ...v }]
      currentData['children'] = [{ ...v }]
      if (v.children) currentData['children'] = v.children
    }
  })
  return currentData
}

onMounted(() => {
  setFilterRoutes();
  mittBus.on('getBreadcrumbIndexSetFilterRoutes', () => {
    setFilterRoutes()
  })
})
// 页面卸载时
onUnmounted(() => {
  mittBus.off('getBreadcrumbIndexSetFilterRoutes', () => { })
})
</script>
<style lang='scss' scoped>
.layout-navbars-breadcrumb-index {
  height: 50px;
  display: flex;
  align-items: center;
  background: var(--next-bg-topBar);
  border-bottom: 1px solid var(--next-border-color-light);
}
</style>